==> refcodes-data-3.1.1-sources.jar: org/refcodes/data/ArgsPrefix.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// /////////////////////////////////////////////////////////////////////////////
// This code is copyright (c) by Siegfried Steiner, Munich, Germany, distributed
// on an "AS IS" BASIS WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, and licen-
// sed under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// -----------------------------------------------------------------------------
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// -----------------------------------------------------------------------------
// Apache License, v2.0 ("http://www.apache.org/licenses/TEXT-2.0")
// -----------------------------------------------------------------------------
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////

package org.refcodes.data;

import org.refcodes.mixin.PrefixAccessor;

/**
 * Commonly used prefixes needful for analyzing, parsing or truncating command
 * line arguments and so on.
 */
public enum ArgsPrefix implements PrefixAccessor {

	/**
	 * A DOS box short option is prefixed with a single slash "/".
	 */
	WINDOWS_SHORT_OPTION("/"),

	/**
	 * A DOS box long option is undefined and herewith prefixed with a double
	 * hyphen-minus "--".
	 */
	WINDOWS_LONG_OPTION("/"),

	/**
	 * A command line argument (POSIX) short-option is prefixed with a single
	 * hyphen-minus "-".
	 */
	POSIX_SHORT_OPTION("-"),

	/**
	 * A command line argument (POSIX) long-option is prefixed with a double
	 * hyphen-minus "--".
	 */
	POSIX_LONG_OPTION("--");

	// /////////////////////////////////////////////////////////////////////////
	// VARIABLES:
	// /////////////////////////////////////////////////////////////////////////

	private String _prefix;

	// /////////////////////////////////////////////////////////////////////////
	// CONSTRUCTORS:
	// /////////////////////////////////////////////////////////////////////////

	/**
	 * Instantiates a new prefix.
	 *
	 * @param aPrefix the prefix
	 */
	private ArgsPrefix( String aPrefix ) {
		_prefix = aPrefix;
	}

	// /////////////////////////////////////////////////////////////////////////
	// METHODS:
	// /////////////////////////////////////////////////////////////////////////

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String getPrefix() {
		return _prefix;
	}

	// /////////////////////////////////////////////////////////////////////////
	// HELPER:
	// /////////////////////////////////////////////////////////////////////////

	/**
	 * Returns an array with all {@link String} prefixes as of
	 * {@link #getPrefix()} defined by this enumeration.
	 * 
	 * @return The array with the according prefixes.
	 */
	public static String[] toPrefixes() {
		String[] theResult = new String[values().length];
		for ( int i = 0; i < values().length; i++ ) {
			theResult[i] = values()[i].getPrefix();
		}
		return theResult;
	}
}

==> refcodes-data-3.3.7-sources.jar: org/refcodes/data/ArgsPrefix.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// /////////////////////////////////////////////////////////////////////////////
// This code is copyright (c) by Siegfried Steiner, Munich, Germany, distributed
// on an "AS IS" BASIS WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, and licen-
// sed under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// -----------------------------------------------------------------------------
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// -----------------------------------------------------------------------------
// Apache License, v2.0 ("http://www.apache.org/licenses/TEXT-2.0")
// -----------------------------------------------------------------------------
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////

package org.refcodes.data;

import org.refcodes.mixin.PrefixAccessor;

/**
 * Commonly used prefixes needful for analyzing, parsing or truncating command
 * line arguments and so on.
 */
public enum ArgsPrefix implements PrefixAccessor {

	/**
	 * A DOS box short option is prefixed with a single slash "/".
	 */
	WINDOWS_SHORT_OPTION("/"),

	/**
	 * A DOS box long option is undefined and herewith prefixed with a double
	 * hyphen-minus "--".
	 */
	WINDOWS_LONG_OPTION("/"),

	/**
	 * A command line argument (POSIX) short-option is prefixed with a single
	 * hyphen-minus "-".
	 */
	POSIX_SHORT_OPTION("-"),

	/**
	 * A command line argument (POSIX) long-option is prefixed with a double
	 * hyphen-minus "--".
	 */
	POSIX_LONG_OPTION("--");

	// /////////////////////////////////////////////////////////////////////////
	// VARIABLES:
	// /////////////////////////////////////////////////////////////////////////

	private String _prefix;

	// /////////////////////////////////////////////////////////////////////////
	// CONSTRUCTORS:
	// /////////////////////////////////////////////////////////////////////////

	/**
	 * Instantiates a new prefix.
	 *
	 * @param aPrefix the prefix
	 */
	private ArgsPrefix( String aPrefix ) {
		_prefix = aPrefix;
	}

	// /////////////////////////////////////////////////////////////////////////
	// METHODS:
	// /////////////////////////////////////////////////////////////////////////

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String getPrefix() {
		return _prefix;
	}

	// /////////////////////////////////////////////////////////////////////////
	// HELPER:
	// /////////////////////////////////////////////////////////////////////////

	/**
	 * Returns an array with all {@link String} prefixes as of
	 * {@link #getPrefix()} defined by this enumeration.
	 * 
	 * @return The array with the according prefixes.
	 */
	public static String[] toPrefixes() {
		final String[] theResult = new String[values().length];
		for ( int i = 0; i < values().length; i++ ) {
			theResult[i] = values()[i].getPrefix();
		}
		return theResult;
	}
}
